@@ -22,6 +22,7 @@
  *          Richard Hult <richard@imendio.com>
  *          Martyn Russell <martyn@imendio.com>
  *          Xavier Claessens <xclaesse@gmail.com>
+ *          Jonny Lamb <jonny.lamb@collabora.co.uk>
  * 
  *          Part of this file is copied from GtkSourceView (gtksourceiter.c):
  *          Paolo Maggi
@@ -40,12 +41,13 @@
 
 #include <libmissioncontrol/mc-profile.h>
 
-#include <libempathy/empathy-debug.h>
-
 #include "empathy-ui-utils.h"
 #include "empathy-images.h"
 
-#define DEBUG_DOMAIN "UiUtils"
+#define DEBUG_FLAG EMPATHY_DEBUG_OTHER
+#include <libempathy/empathy-debug.h>
+#include <libempathy/empathy-utils.h>
+#include <libempathy/empathy-dispatcher.h>
 
 struct SizeData {
 	gint     width;
@@ -64,7 +66,7 @@ get_glade_file (const gchar *filename,
 	const char *name;
 	GtkWidget **widget_ptr;
 
-	empathy_debug (DEBUG_DOMAIN, "Loading glade file %s", filename);
+	DEBUG ("Loading glade file %s", filename);
 
 	gui = glade_xml_new (filename, root, domain);
 
@@ -248,9 +250,19 @@ empathy_icon_name_for_contact (EmpathyContact *contact)
 GdkPixbuf *
 empathy_pixbuf_from_data (gchar *data,
 			  gsize  data_size)
+{
+	return empathy_pixbuf_from_data_and_mime (data, data_size, NULL);
+}
+
+GdkPixbuf *
+empathy_pixbuf_from_data_and_mime (gchar  *data,
+				   gsize   data_size,
+				   gchar **mime_type)
 {
 	GdkPixbufLoader *loader;
+	GdkPixbufFormat *format;
 	GdkPixbuf       *pixbuf = NULL;
+	gchar          **mime_types;
 	GError          *error = NULL;
 
 	if (!data) {
@@ -259,25 +271,36 @@ empathy_pixbuf_from_data (gchar *data,
 
 	loader = gdk_pixbuf_loader_new ();
 	if (!gdk_pixbuf_loader_write (loader, data, data_size, &error)) {
-		empathy_debug (DEBUG_DOMAIN, "Failed to write to pixbuf loader: %s",
-			       error ? error->message : "No error given");
-		g_clear_error (&error);
-		g_object_unref (loader);
-		return NULL;
+		DEBUG ("Failed to write to pixbuf loader: %s",
+			error ? error->message : "No error given");
+		goto out;
 	}
 	if (!gdk_pixbuf_loader_close (loader, &error)) {
-		empathy_debug (DEBUG_DOMAIN, "Failed to close pixbuf loader: %s",
-			       error ? error->message : "No error given");
-		g_clear_error (&error);
-		g_object_unref (loader);
-		return NULL;
+		DEBUG ("Failed to close pixbuf loader: %s",
+			error ? error->message : "No error given");
+		goto out;
 	}
 
 	pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
 	if (pixbuf) {
 		g_object_ref (pixbuf);
+
+		if (mime_type != NULL) {
+			format = gdk_pixbuf_loader_get_format (loader);
+			mime_types = gdk_pixbuf_format_get_mime_types (format);
+
+			*mime_type = g_strdup (*mime_types);
+			if (mime_types[1] != NULL) {
+				DEBUG ("Loader supports more than one mime "
+					"type! Picking the first one, %s",
+					*mime_type);
+			}
+			g_strfreev (mime_types);
+		}
 	}
 
+out:
+	g_clear_error (&error);
 	g_object_unref (loader);
 
 	return pixbuf;
@@ -487,7 +510,7 @@ empathy_pixbuf_scale_down_if_necessary (GdkPixbuf *pixbuf, gint max_size)
 	width = gdk_pixbuf_get_width (pixbuf);
 	height = gdk_pixbuf_get_height (pixbuf);
 
-	if (width > max_size || height > max_size) {
+	if (width > 0 && (width > max_size || height > max_size)) {
 		factor = (gdouble) max_size / MAX (width, height);
 
 		width = width * factor;
@@ -527,7 +550,7 @@ empathy_pixbuf_from_icon_name (const gchar *icon_name,
 					   0,
 					   &error);
 	if (error) {
-		empathy_debug (DEBUG_DOMAIN, "Error loading icon: %s", error->message);
+		DEBUG ("Error loading icon: %s", error->message);
 		g_clear_error (&error);
 	}
 
@@ -1295,13 +1318,17 @@ empathy_get_toplevel_window (GtkWidget *widget)
 static gchar *
 fixup_url (const gchar *url)
 {
-	if (!g_str_has_prefix (url, "ghelp:") &&
-	    !strstr (url, ":/") &&
-	    !strstr (url, "@")) {
-		return g_strdup_printf ("http://%s", url);
-	} else {
+	if (g_str_has_prefix (url, "ghelp:") ||
+	    g_str_has_prefix (url, "mailto:") ||
+	    strstr (url, ":/")) {
 		return NULL;
 	}
+
+	if (strstr (url, "@")) {
+		return g_strdup_printf ("mailto:%s", url);
+	}
+
+	return g_strdup_printf ("http://%s", url);
 }
 
 void
@@ -1324,9 +1351,9 @@ empathy_url_show (const char *url)
 
 		dialog = gtk_message_dialog_new (NULL, 0,
 						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
-						 _("Unable to open uri"));
+						 _("Unable to open URI"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  error->message);
+							  "%s", error->message);
 
 		g_signal_connect (dialog, "response",
 				  G_CALLBACK (gtk_widget_destroy),
@@ -1422,3 +1449,76 @@ empathy_text_buffer_tag_set (GtkTextBuffer *buffer,
 	return tag;
 }
 
+/* Sending files with the file chooser */
+
+static void
+file_manager_send_file_response_cb (GtkDialog      *widget,
+				    gint            response_id,
+				    EmpathyContact *contact)
+{
+	if (response_id == GTK_RESPONSE_OK) {
+		GSList *list;
+		GSList *l;
+
+		list = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (widget));
+
+		DEBUG ("File chooser selected files:");
+
+		for (l = list; l; l = l->next) {
+			gchar            *uri;
+			GFile            *gfile;
+			GtkRecentManager *manager;
+
+			uri = l->data;
+			gfile = g_file_new_for_uri (uri);
+
+			DEBUG ("\t%s", uri);
+			empathy_dispatcher_send_file (contact, gfile);
+
+			manager = gtk_recent_manager_get_default ();
+			gtk_recent_manager_add_item (manager, uri);
+
+			g_object_unref (gfile);
+			g_free (uri);
+		}
+		g_slist_free (list);
+	}
+
+	gtk_widget_destroy (GTK_WIDGET (widget));
+}
+
+void
+empathy_send_file_with_file_chooser (EmpathyContact *contact)
+{
+	GtkWidget               *widget;
+	GtkWidget               *button;
+
+	g_return_if_fail (EMPATHY_IS_CONTACT (contact));
+
+	DEBUG ("Creating selection file chooser");
+
+	widget = gtk_file_chooser_dialog_new (_("Select a file"),
+					      NULL,
+					      GTK_FILE_CHOOSER_ACTION_OPEN,
+					      GTK_STOCK_CANCEL,
+					      GTK_RESPONSE_CANCEL,
+					      NULL);
+
+	/* send button */
+	button = gtk_button_new_with_mnemonic (_("_Send"));
+	gtk_button_set_image (GTK_BUTTON (button),
+		gtk_image_new_from_icon_name (EMPATHY_IMAGE_DOCUMENT_SEND,
+					      GTK_ICON_SIZE_BUTTON));
+	gtk_widget_show (button);
+	gtk_dialog_add_action_widget (GTK_DIALOG (widget), button,
+				      GTK_RESPONSE_OK);
+	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_dialog_set_default_response (GTK_DIALOG (widget),
+					 GTK_RESPONSE_OK);
+
+	g_signal_connect (widget, "response",
+			  G_CALLBACK (file_manager_send_file_response_cb),
+			  contact);
+
+	gtk_widget_show (widget);
+}
