@@ -24,6 +24,7 @@
 #include <string.h>
 
 #include <glib.h>
+#include <telepathy-glib/util.h>
 
 #include "empathy-chatroom.h"
 #include "empathy-utils.h"
@@ -34,6 +35,11 @@ typedef struct {
 	gchar     *room;
 	gchar     *name;
 	gboolean   auto_connect;
+  gboolean favorite;
+  /* FIXME: This is crack. We should store EmapthyTpChat but can't
+   * as it's not created in the dispatcher. At some point it should be
+   * automatically created by tp-glib */
+  TpChannel *tp_channel;
 } EmpathyChatroomPriv;
 
 
@@ -53,6 +59,8 @@ enum {
 	PROP_ROOM,
 	PROP_NAME,
 	PROP_AUTO_CONNECT,
+  PROP_FAVORITE,
+  PROP_TP_CHANNEL
 };
 
 G_DEFINE_TYPE (EmpathyChatroom, empathy_chatroom, G_TYPE_OBJECT);
@@ -98,6 +106,30 @@ empathy_chatroom_class_init (EmpathyChatroomClass *klass)
 							       FALSE,
 							       G_PARAM_READWRITE));
 
+  g_object_class_install_property (object_class,
+      PROP_FAVORITE,
+      g_param_spec_boolean ("favorite",
+        "Favorite",
+        "TRUE if the chatroom is in user's favorite list",
+        FALSE,
+        G_PARAM_READWRITE |
+        G_PARAM_CONSTRUCT |
+        G_PARAM_STATIC_NAME |
+        G_PARAM_STATIC_NICK |
+        G_PARAM_STATIC_BLURB));
+
+  g_object_class_install_property (object_class,
+      PROP_TP_CHANNEL,
+      g_param_spec_object ("tp-channel",
+        "TpChannel object",
+        "The TpChannel associated with this chatroom if we are in the"
+        " room. NULL otherwise.",
+        TP_TYPE_CHANNEL,
+        G_PARAM_READWRITE |
+        G_PARAM_CONSTRUCT |
+        G_PARAM_STATIC_NAME |
+        G_PARAM_STATIC_NICK |
+        G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (object_class, sizeof (EmpathyChatroomPriv));
 }
@@ -118,6 +150,12 @@ chatroom_finalize (GObject *object)
 
 	priv = GET_PRIV (object);
 
+  if (priv->tp_channel != NULL)
+    {
+      g_object_unref (priv->tp_channel);
+      priv->tp_channel = NULL;
+    }
+
 	g_object_unref (priv->account);
 	g_free (priv->room);
 	g_free (priv->name);
@@ -148,6 +186,12 @@ chatroom_get_property (GObject    *object,
 	case PROP_AUTO_CONNECT:
 		g_value_set_boolean (value, priv->auto_connect);
 		break;
+  case PROP_FAVORITE:
+    g_value_set_boolean (value, priv->favorite);
+    break;
+  case PROP_TP_CHANNEL:
+    g_value_set_object (value, priv->tp_channel);
+    break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -181,6 +225,22 @@ chatroom_set_property (GObject      *object,
 		empathy_chatroom_set_auto_connect (EMPATHY_CHATROOM (object),
 						  g_value_get_boolean (value));
 		break;
+  case PROP_FAVORITE:
+    priv->favorite = g_value_get_boolean (value);
+    if (!priv->favorite)
+      {
+        empathy_chatroom_set_auto_connect (EMPATHY_CHATROOM (object),
+            FALSE);
+      }
+    break;
+  case PROP_TP_CHANNEL:
+    if (priv->tp_channel != NULL)
+      {
+        g_object_unref (priv->tp_channel);
+      }
+
+    priv->tp_channel = g_value_dup_object (value);
+    break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -188,15 +248,12 @@ chatroom_set_property (GObject      *object,
 }
 
 EmpathyChatroom *
-empathy_chatroom_new (McAccount   *account,
-		     const gchar *room)
+empathy_chatroom_new (McAccount *account)
 {
 	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
-	g_return_val_if_fail (room != NULL, NULL);
 
 	return g_object_new (EMPATHY_TYPE_CHATROOM,
 			     "account", account,
-			     "room", room,
 			     NULL);
 }
 
@@ -336,6 +393,13 @@ empathy_chatroom_set_auto_connect (EmpathyChatroom *chatroom,
 
 	priv->auto_connect = auto_connect;
 
+  if (priv->auto_connect)
+    {
+      /* auto_connect implies favorite */
+      priv->favorite = TRUE;
+      g_object_notify (G_OBJECT (chatroom), "favorite");
+    }
+
 	g_object_notify (G_OBJECT (chatroom), "auto-connect");
 }
 
@@ -357,7 +421,6 @@ empathy_chatroom_equal (gconstpointer v1,
 	room_a = empathy_chatroom_get_room (EMPATHY_CHATROOM (v1));
 	room_b = empathy_chatroom_get_room (EMPATHY_CHATROOM (v2));
 
-	return empathy_account_equal (account_a, account_b) && g_str_equal (room_a, room_b);
+	return empathy_account_equal (account_a, account_b) && !tp_strdiff (room_a,
+      room_b);
 }
-
-
