@@ -44,8 +44,10 @@
 #include <libempathy-gtk/empathy-account-widget.h>
 #include <libempathy-gtk/empathy-account-widget-irc.h>
 #include <libempathy-gtk/empathy-account-widget-sip.h>
+#include <libempathy-gtk/empathy-conf.h>
 
 #include "empathy-accounts-dialog.h"
+#include "empathy-import-dialog.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
 #include <libempathy/empathy-debug.h>
@@ -65,6 +67,7 @@ typedef struct {
 
 	GtkWidget        *button_add;
 	GtkWidget        *button_remove;
+	GtkWidget        *button_import;
 
 	GtkWidget        *frame_new_account;
 	GtkWidget        *combobox_profile;
@@ -144,6 +147,8 @@ static void       accounts_dialog_button_help_clicked_cb    (GtkWidget
 							     EmpathyAccountsDialog    *dialog);
 static void       accounts_dialog_button_remove_clicked_cb  (GtkWidget                *button,
 							     EmpathyAccountsDialog    *dialog);
+static void       accounts_dialog_button_import_clicked_cb  (GtkWidget                *button,
+							     EmpathyAccountsDialog    *dialog);
 static void       accounts_dialog_response_cb               (GtkWidget                *widget,
 							     gint                      response,
 							     EmpathyAccountsDialog    *dialog);
@@ -998,6 +1003,13 @@ accounts_dialog_button_remove_clicked_cb (GtkWidget            *button,
 	gtk_widget_destroy (message_dialog);
 }
 
+static void
+accounts_dialog_button_import_clicked_cb (GtkWidget             *button,
+					  EmpathyAccountsDialog *dialog)
+{
+	empathy_import_dialog_show (GTK_WINDOW (dialog->window), TRUE);
+}
+
 static void
 accounts_dialog_response_cb (GtkWidget            *widget,
 			     gint                  response,
@@ -1063,6 +1075,7 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 	GladeXML                     *glade;
 	gchar                        *filename;
 	GList                        *accounts, *l;
+	gboolean                      import_asked;
 
 	if (dialog) {
 		gtk_window_present (GTK_WINDOW (dialog->window));
@@ -1090,6 +1103,7 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 				       "label_name", &dialog->label_name,
 				       "button_add", &dialog->button_add,
 				       "button_remove", &dialog->button_remove,
+				       "button_import", &dialog->button_import,
 				       NULL);
 	g_free (filename);
 
@@ -1101,6 +1115,7 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 			      "button_back", "clicked", accounts_dialog_button_back_clicked_cb,
 			      "button_add", "clicked", accounts_dialog_button_add_clicked_cb,
 			      "button_remove", "clicked", accounts_dialog_button_remove_clicked_cb,
+			      "button_import", "clicked", accounts_dialog_button_import_clicked_cb,
 			      "button_help", "clicked", accounts_dialog_button_help_clicked_cb,
 			      NULL);
 
@@ -1164,6 +1179,16 @@ empathy_accounts_dialog_show (GtkWindow *parent,
 
 	gtk_widget_show (dialog->window);
 
+	empathy_conf_get_bool (empathy_conf_get (),
+			       EMPATHY_PREFS_IMPORT_ASKED, &import_asked);
+
+	if (!import_asked) {
+		empathy_conf_set_bool (empathy_conf_get (),
+				       EMPATHY_PREFS_IMPORT_ASKED, TRUE);
+		empathy_import_dialog_show (GTK_WINDOW (dialog->window),
+					    FALSE);
+	}
+
 	return dialog->window;
 }
 
