@@ -226,6 +226,7 @@ chat_window_create_label (EmpathyChatWindow *window,
 
 	close_button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
+	g_object_set_data (G_OBJECT (chat), "chat-window-tab-close-button", close_button);
 
 	/* We don't want focus/keynav for the button to avoid clutter, and
 	 * Ctrl-W works anyway.
@@ -262,23 +263,6 @@ chat_window_create_label (EmpathyChatWindow *window,
 	return hbox;
 }
 
-static const gchar *
-chat_window_get_chat_name (EmpathyChat *chat)
-{
-	EmpathyContact *remote_contact = NULL;
-	const gchar    *name = NULL;
-
-	name = empathy_chat_get_name (chat);
-	if (!name) {
-		remote_contact = empathy_chat_get_remote_contact (chat);
-		if (remote_contact) {
-			name = empathy_contact_get_name (remote_contact);
-		}
-	}
-
-	return name ? name : _("Conversation");
-}
-
 static void
 chat_window_update (EmpathyChatWindow *window)
 {
@@ -288,11 +272,14 @@ chat_window_update (EmpathyChatWindow *window)
 	gboolean               is_connected;
 	gint                   num_pages;
 	gint                   page_num;
+	gint                   i;
 	const gchar           *name;
 	guint                  n_chats;
 	GdkPixbuf             *icon;
 	EmpathyContact        *remote_contact;
 	gboolean               avatar_in_icon;
+	GtkWidget             *chat;
+	GtkWidget             *chat_close_button;
 
 	/* Get information */
 	page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook));
@@ -300,7 +287,7 @@ chat_window_update (EmpathyChatWindow *window)
 	first_page = (page_num == 0);
 	last_page = (page_num == (num_pages - 1));
 	is_connected = empathy_chat_get_tp_chat (priv->current_chat) != NULL;
-	name = chat_window_get_chat_name (priv->current_chat);
+	name = empathy_chat_get_name (priv->current_chat);
 	n_chats = g_list_length (priv->chats);
 
 	DEBUG ("Update window");
@@ -342,6 +329,20 @@ chat_window_update (EmpathyChatWindow *window)
 			gtk_window_set_icon_name (GTK_WINDOW (priv->dialog), NULL);
 		}
 	}
+
+	if (num_pages == 1) {
+		chat = gtk_notebook_get_nth_page (GTK_NOTEBOOK (priv->notebook), 0);
+		chat_close_button = g_object_get_data (G_OBJECT (chat),
+				"chat-window-tab-close-button");
+		gtk_widget_hide (chat_close_button);
+	} else {
+		for (i=0; i<num_pages; i++) {
+			chat = gtk_notebook_get_nth_page (GTK_NOTEBOOK (priv->notebook), i);
+			chat_close_button = g_object_get_data (G_OBJECT (chat),
+					"chat-window-tab-close-button");
+			gtk_widget_show (chat_close_button);
+		}
+	}
 }
 
 static void
@@ -351,10 +352,11 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 	EmpathyChatWindowPriv *priv;
 	EmpathyContact        *remote_contact;
 	const gchar           *name;
+	McAccount             *account;
 	const gchar           *subject;
 	GtkWidget             *widget;
 	GString               *tooltip;
-	gchar                 *str;
+	gchar                 *markup;
 	const gchar           *icon_name;
 
 	window = chat_window_find_chat (chat);
@@ -364,12 +366,13 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 	priv = GET_PRIV (window);
 
 	/* Get information */
-	name = chat_window_get_chat_name (chat);
+	name = empathy_chat_get_name (chat);
+	account = empathy_chat_get_account (chat);
 	subject = empathy_chat_get_subject (chat);
 	remote_contact = empathy_chat_get_remote_contact (chat);
 
-	DEBUG ("Updating chat tab, name=%s, subject=%s, remote_contact=%p",
-		name, subject, remote_contact);
+	DEBUG ("Updating chat tab, name=%s, account=%s, subject=%s, remote_contact=%p",
+		name, mc_account_get_unique_name (account), subject, remote_contact);
 
 	/* Update tab image */
 	if (g_list_find (priv->chats_new_msg, chat)) {
@@ -388,24 +391,37 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 
 	/* Update tab tooltip */
 	tooltip = g_string_new (NULL);
+
 	if (remote_contact) {
-		g_string_append_printf (tooltip, "%s\n%s",
-					empathy_contact_get_id (remote_contact),
-					empathy_contact_get_status (remote_contact));
+		markup = g_markup_printf_escaped ("<b>%s</b><small> (%s)</small>\n%s",
+						  empathy_contact_get_id (remote_contact),
+						  mc_account_get_display_name (account),
+						  empathy_contact_get_status (remote_contact));
+		g_string_append (tooltip, markup);
+		g_free (markup);
 	}
 	else {
-		g_string_append (tooltip, name);
+		markup = g_markup_printf_escaped ("<b>%s</b><small>  (%s)</small>", name,
+						  mc_account_get_display_name (account));
+		g_string_append (tooltip, markup);
+		g_free (markup);
 	}
+
 	if (subject) {
-		g_string_append_printf (tooltip, "\n%s %s", _("Topic:"), subject);
+		markup = g_markup_printf_escaped ("\n<b>%s</b> %s", _("Topic:"), subject);
+		g_string_append (tooltip, markup);
+		g_free (markup);
 	}
 	if (g_list_find (priv->chats_composing, chat)) {
-		g_string_append_printf (tooltip, "\n%s", _("Typing a message."));
+		markup = g_markup_printf_escaped ("\n%s", _("Typing a message."));
+		g_string_append (tooltip, markup);
+		g_free (markup);
 	}
-	str = g_string_free (tooltip, FALSE);
+
+	markup = g_string_free (tooltip, FALSE);
 	widget = g_object_get_data (G_OBJECT (chat), "chat-window-tab-tooltip-widget");
-	gtk_widget_set_tooltip_text (widget, str);
-	g_free (str);
+	gtk_widget_set_tooltip_markup (widget, markup);
+	g_free (markup);
 
 	/* Update tab label */
 	widget = g_object_get_data (G_OBJECT (chat), "chat-window-tab-label");
@@ -1217,7 +1233,7 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 
 	g_object_unref (glade);
 
-	priv->chatroom_manager = empathy_chatroom_manager_new ();
+	priv->chatroom_manager = empathy_chatroom_manager_new (NULL);
 
 	priv->notebook = gtk_notebook_new ();
  	gtk_notebook_set_group (GTK_NOTEBOOK (priv->notebook), "EmpathyChatWindow"); 
