@@ -24,6 +24,7 @@
 
 #include <stdlib.h>
 #include <errno.h>
+#include <string.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -40,14 +41,18 @@
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-dispatcher.h>
 #include <libempathy/empathy-tp-chat.h>
-#include <libempathy/empathy-tp-call.h>
+#include <libempathy/empathy-tp-group.h>
 
 #include <libempathy-gtk/empathy-conf.h>
 
+#include <extensions/extensions.h>
+
+#include "empathy-accounts-dialog.h"
 #include "empathy-main-window.h"
 #include "empathy-status-icon.h"
 #include "empathy-call-window.h"
 #include "empathy-chat-window.h"
+#include "empathy-ft-manager.h"
 #include "bacon-message-connection.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
@@ -60,9 +65,9 @@ dispatch_channel_cb (EmpathyDispatcher *dispatcher,
 		     TpChannel         *channel,
 		     gpointer           user_data)
 {
-	gchar *channel_type;
+	const gchar *channel_type;
 
-	g_object_get (channel, "channel-type", &channel_type, NULL);
+	channel_type = tp_channel_get_channel_type (channel);
 	if (!tp_strdiff (channel_type, TP_IFACE_CHANNEL_TYPE_TEXT)) {
 		EmpathyTpChat *tp_chat;
 		EmpathyChat   *chat = NULL;
@@ -98,11 +103,16 @@ dispatch_channel_cb (EmpathyDispatcher *dispatcher,
 		g_object_unref (tp_chat);
 	}
 	else if (!tp_strdiff (channel_type, TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA)) {
-		EmpathyTpCall *tp_call;
+		empathy_call_window_new (channel);
+	}
+	else if (!tp_strdiff (channel_type, EMP_IFACE_CHANNEL_TYPE_FILE_TRANSFER)) {
+		EmpathyFTManager *ft_manager;
+		EmpathyTpFile    *tp_file;
 
-		tp_call = empathy_tp_call_new (channel);
-		empathy_call_window_new (tp_call);
-		g_object_unref (tp_call);
+		ft_manager = empathy_ft_manager_get_default ();
+		tp_file = empathy_tp_file_new (channel);
+		empathy_ft_manager_add_tp_file (ft_manager, tp_file);
+		g_object_unref (tp_file);
 	}
 }
 
@@ -123,46 +133,46 @@ operation_error_cb (MissionControl *mc,
 
 	switch (error_code) {
 	case MC_DISCONNECTED_ERROR:
-		message = _("Disconnected");
+		message = "Disconnected";
 		break;
 	case MC_INVALID_HANDLE_ERROR:
-		message = _("Invalid handle");
+		message = "Invalid handle";
 		break;
 	case MC_NO_MATCHING_CONNECTION_ERROR:
-		message = _("No matching connection");
+		message = "No matching connection";
 		break;
 	case MC_INVALID_ACCOUNT_ERROR:
-		message = _("Invalid account");
+		message = "Invalid account";
 		break;
 	case MC_PRESENCE_FAILURE_ERROR:
-		message = _("Presence failure");
+		message = "Presence failure";
 		break;
 	case MC_NO_ACCOUNTS_ERROR:
-		message = _("No accounts");
+		message = "No accounts";
 		break;
 	case MC_NETWORK_ERROR:
-		message = _("Network error");
+		message = "Network error";
 		break;
 	case MC_CONTACT_DOES_NOT_SUPPORT_VOICE_ERROR:
-		message = _("Contact does not support voice");
+		message = "Contact does not support voice";
 		break;
 	case MC_LOWMEM_ERROR:
-		message = _("Lowmem");
+		message = "Lowmem";
 		break;
 	case MC_CHANNEL_REQUEST_GENERIC_ERROR:
-		message = _("Channel request generic error");
+		message = "Channel request generic error";
 		break;
 	case MC_CHANNEL_BANNED_ERROR:
-		message = _("Channel banned");
+		message = "Channel banned";
 		break;
 	case MC_CHANNEL_FULL_ERROR:
-		message = _("Channel full");
+		message = "Channel full";
 		break;
 	case MC_CHANNEL_INVITE_ONLY_ERROR:
-		message = _("Channel invite only");
+		message = "Channel invite only";
 		break;
 	default:
-		message = _("Unknown error code");
+		message = "Unknown error code";
 	}
 
 	DEBUG ("Error during operation %d: %s", operation_id, message);
@@ -210,6 +220,10 @@ create_salut_account (void)
 
 	/* Check if the salut CM is installed */
 	profile = mc_profile_lookup ("salut");
+	if (!profile) {
+		DEBUG ("No salut profile");
+		return;
+	}
 	protocol = mc_profile_get_protocol (profile);
 	if (!protocol) {
 		DEBUG ("Salut not installed");
@@ -292,25 +306,30 @@ on_bacon_message_received (const char *message,
 	DEBUG ("Other instance launched, presenting the main window. message='%s'",
 		message);
 
-	startup_timestamp = atoi (message);
+	if (strcmp (message, "accounts") == 0) {
+		/* accounts dialog requested */
+		empathy_accounts_dialog_show (GTK_WINDOW (window), NULL);
+	} else {
+		startup_timestamp = atoi (message);
 
-	/* Set the proper interaction time on the window.
-	 * Fall back to roundtripping to the X server when we
-	 * don't have the timestamp, e.g. when launched from
-	 * terminal. We also need to make sure that the window
-	 * has been realized otherwise it will not work. lame. */
-	if (startup_timestamp == 0) {
-		/* Work if launched from the terminal */
-		DEBUG ("Using X server timestamp as a fallback");
+		/* Set the proper interaction time on the window.
+		 * Fall back to roundtripping to the X server when we
+		 * don't have the timestamp, e.g. when launched from
+		 * terminal. We also need to make sure that the window
+		 * has been realized otherwise it will not work. lame. */
+		if (startup_timestamp == 0) {
+			/* Work if launched from the terminal */
+			DEBUG ("Using X server timestamp as a fallback");
 
-		if (!GTK_WIDGET_REALIZED (window)) {
-			gtk_widget_realize (GTK_WIDGET (window));
+			if (!GTK_WIDGET_REALIZED (window)) {
+				gtk_widget_realize (GTK_WIDGET (window));
+			}
+
+			startup_timestamp = gdk_x11_get_server_time (window->window);
 		}
 
-		startup_timestamp = gdk_x11_get_server_time (window->window);
+		gtk_window_present_with_time (GTK_WINDOW (window), startup_timestamp);
 	}
-
-	gtk_window_present_with_time (GTK_WINDOW (window), startup_timestamp);
 }
 
 static guint32
@@ -362,12 +381,22 @@ main (int argc, char *argv[])
 	EmpathyIdle       *idle;
 	gboolean           autoconnect = TRUE;
 	gboolean           no_connect = FALSE; 
+	gboolean           hide_contact_list = FALSE;
+	gboolean           accounts_dialog = FALSE;
 	GError            *error = NULL;
 	GOptionEntry       options[] = {
 		{ "no-connect", 'n',
 		  0, G_OPTION_ARG_NONE, &no_connect,
 		  N_("Don't connect on startup"),
 		  NULL },
+		{ "hide-contact-list", 'h',
+		  0, G_OPTION_ARG_NONE, &hide_contact_list,
+		  N_("Don't show the contact list on startup"),
+		  NULL },
+		{ "accounts", 'a',
+		  0, G_OPTION_ARG_NONE, &accounts_dialog,
+		  N_("Show the accounts dialog"),
+		  NULL },
 		{ NULL }
 	};
 
@@ -402,10 +431,19 @@ main (int argc, char *argv[])
 		if (!bacon_message_connection_get_is_server (connection)) {
 			gchar *message;
 
-			DEBUG ("Activating existing instance");
+			if (accounts_dialog) {
+				DEBUG ("Showing accounts dialog from existing Empathy instance");
+
+				message = g_strdup ("accounts");
+
+			} else {
+
+				DEBUG ("Activating existing instance");
+
+				message = g_strdup_printf ("%" G_GUINT32_FORMAT,
+							   startup_timestamp);
+			}
 
-			message = g_strdup_printf ("%" G_GUINT32_FORMAT,
-						   startup_timestamp);
 			bacon_message_connection_send (connection, message);
 
 			/* We never popup a window, so tell startup-notification
@@ -421,6 +459,8 @@ main (int argc, char *argv[])
 		g_warning ("Cannot create the 'empathy' bacon connection.");
 	}
 
+	emp_cli_init ();
+
 	/* Setting up MC */
 	mc = empathy_mission_control_new ();
 	g_signal_connect (mc, "ServiceEnded",
@@ -430,6 +470,18 @@ main (int argc, char *argv[])
 			  G_CALLBACK (operation_error_cb),
 			  NULL);
 
+	if (accounts_dialog) {
+		GtkWidget *dialog;
+
+		dialog = empathy_accounts_dialog_show (NULL, NULL);
+		g_signal_connect (dialog, "destroy",
+				  G_CALLBACK (gtk_main_quit),
+				  NULL);
+
+		gtk_main ();
+		return 0;
+	}
+
 	/* Setting up Idle */
 	idle = empathy_idle_new ();
 	empathy_idle_set_auto_away (idle, TRUE);
@@ -450,7 +502,7 @@ main (int argc, char *argv[])
 
 	/* Setting up UI */
 	window = empathy_main_window_show ();
-	icon = empathy_status_icon_new (GTK_WINDOW (window));
+	icon = empathy_status_icon_new (GTK_WINDOW (window), hide_contact_list);
 
 	if (connection) {
 		/* We se the callback here because we need window */
