@@ -19,6 +19,8 @@ make_libempathy_suite (void)
     suite_add_tcase (s, make_empathy_irc_server_tcase ());
     suite_add_tcase (s, make_empathy_irc_network_tcase ());
     suite_add_tcase (s, make_empathy_irc_network_manager_tcase ());
+    suite_add_tcase (s, make_empathy_chatroom_tcase ());
+    suite_add_tcase (s, make_empathy_chatroom_manager_tcase ());
 
     return s;
 }
